==> cmsmadesimple-1.6.6.tgz: cms/modules/FileManager/lang/ext/ro_RO.php <==
<?php
$lang['friendlyname'] = 'Management fisiere';
$lang['permission'] = 'Mod de folosire al modulului de management fisiere';
$lang['permissionadvanced'] = 'Mod de folosire avansata al modulului de management fisiere';
$lang['moddescription'] = 'Gestionarea fisierelor si folderelor in sectiunea upload a cmsms';
$lang['installed'] = 'FileManager versiunea %s instalata';
$lang['postinstall'] = 'Modulul FileManager a fost instalat';
$lang['uninstalled'] = 'Modulul FileManager a fost dezinstalat';
$lang['really_uninstall'] = 'Sigur doriti ca modulul FileManager sa fie dezinstalat?';
$lang['upgraded'] = 'Modulul FileManager a fost actualizat la verisunea %s';
$lang['fileview'] = 'Vizualizare fisiere';
$lang['switchtofileview'] = 'Schimbare pe vizualizare fisiere';
$lang['settings'] = 'Setari';
$lang['savesettings'] = 'Salvare setari';
$lang['filename'] = 'Nume fisier';
$lang['fileinfo'] = 'Info fisier';
$lang['fileowner'] = 'Proprietar fisier';
$lang['fileperms'] = 'Permisiuni';
$lang['filesize'] = 'Dimensiune';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Actiuni';
$lang['delete'] = 'Stergere';
$lang['notwritable'] = 'Nu are permisiuni de scriere';
$lang['filetoobig'] = 'este prea mare. Upload anulat.';
$lang['unknown'] = 'Necunoscut';
$lang['fileoutsideuploads'] = 'Nu puteti sa modificati fisiere din afara folderului uploads! (Pentru aceasta este nevoie de permisiuni pentru management fisiere avansat)';
$lang['writable'] = 'Se poate scrie';
$lang['writeprotected'] = 'Protejat la scriere';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'fisiere';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'fisier';
$lang['fileno'] = 'Fisier nr.';
$lang['subdirs'] = 'subfoldere';
$lang['subdir'] = 'subfolder';
$lang['and'] = 'si';
$lang['confirmsingledelete'] = 'Sunteti sigur?';
$lang['confirmsingledirdelete'] = 'Sunteit sigur ca acest  folder ar trebui sters?';
$lang['dirtreedeletesuccess'] = 'Folderul (inclusiv continutul sau) a fost sters.';
$lang['dirtreedeletefail'] = 'A aparut o eroare la stergerea acestui folder. O parte din continut e posibil sa fie sters, totusi.';
$lang['singlefiledeletesuccess'] = 'Fisierul a fost sters';
$lang['filedeletesuccess'] = 'a fost sters cu succes';
$lang['singlefiledeletefail'] = 'O eroare a aparut la stergerea fisierului';
$lang['filedeletefail'] = ' nu a fost sters din cauza unei erori';
$lang['singledirdeletesuccess'] = 'Folderul a fost sters cu succes';
$lang['singledirdeletefail'] = 'O eroare a aparut cand incercam stergerea folderului (este gol?)';
$lang['deleteselected'] = 'Stergere fisiere selectate';
$lang['confirmselected'] = 'Sunteti sigur?';
$lang['confirmdeleteselected'] = 'Sigur doriti ca fisierele selectate ar trebui sa fie sterse?';
$lang['deleteselectedcancelled'] = 'Stergerea fisierelor selectate a fost anulata';
$lang['recursetext'] = 'Recursiune in subdirectoare';
$lang['nofilesselected'] = 'Nici un fisier selectat';
$lang['moveselected'] = 'Mutare fisiere selectate';
$lang['copyselected'] = 'Copiere fisiere selectate';
$lang['selecttargetdir'] = 'Selectare folder tinta pentru mutare/copiere';
$lang['movedto'] = 'mutat la';
$lang['copiedto'] = 'copiat la';
$lang['couldnotmove'] = 'nu a putut fi mutat';
$lang['couldnotcopy'] = 'nu a putut fi copiat';
$lang['rename'] = 'Redenumire';
$lang['newname'] = 'Nume nou:';
$lang['renamesuccess'] = 'Fisier redenumit cu succes';
$lang['renamefailure'] = 'Redenumire fisier esuata';
$lang['renamecancelled'] = 'Redenumire anulata';
$lang['owner'] = 'Proprietar';
$lang['group'] = 'Grup';
$lang['others'] = 'Altele';
$lang['newpermissions'] = 'Permisiuni noi:';
$lang['setpermissions'] = 'Setare permisiuni';
$lang['permissionstyle'] = 'Stil permisiuni';
$lang['rwxstyle'] = 'stil rwx';
$lang['755style'] = 'stil 755';
$lang['quickmode'] = 'Chmod rapid (ca si 777)';
$lang['chmod'] = 'Modificare permisiuni';
$lang['chmodselected'] = 'Modificare permisiuni pentru fisierele selectate';
$lang['chmodsuccess'] = 'Fisierul a primit cu succes permisiuni noi';
$lang['chmodfailure'] = 'Schimbare permisiuni fisier esuata';
$lang['chmodcancelled'] = 'Schimbare permisiuni anulata';
$lang['dirchmodfailmulti'] = 'Schimbare permisiuni pentru folder esuata, o parte din continut e posibil sa fi primit permisiuni noi, totusi.';
$lang['dirchmodsuccessmulti'] = 'Schimbare permisiuni pentru folder si continut reusita';
$lang['dirchmodsuccess'] = 'Folderul a primit cu succes permisiuni noi';
$lang['dirchmodfailure'] = 'Schimbare permisiuni pentru folder esuata';
$lang['dirnotemptyconfirm'] = 'Acest folder nu este gol. Sigur doriti sa il stergeti impreuna cu tot continutul sau, incluzand subfolderele?';
$lang['dirtreedeletecancelled'] = 'Stergere folder anulata';
$lang['imsure'] = 'Sunt sigur';
$lang['cancel'] = 'Anulare';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Upload fisiere noi:';
$lang['unpackafterupload'] = 'Se incearca despachetare fisier dupa upload (numai tgz si mare parte din arhivele de tip zip)?';
$lang['uploadsuccess'] = 'a fost uploadat cu succes';
$lang['uploadfail'] = 'a esuat uploadarea';
$lang['unpacksuccess'] = 'a fost despachetat cu succes';
$lang['unpackfail'] = 'a esuat cu eroarea: ';
$lang['packfileopenfail'] = 'Nu s-a putut deschide fisierul arhivat pentru despachetare (format nesuportat?)';
$lang['packfilewritefail'] = 'Nu s-a putut deschide fisierul %s pentru scriere';
$lang['currentpath'] = 'Cale curenta:';
$lang['newdirname'] = 'Creare folder nou:';
$lang['newdirsuccess'] = 'Folderul a fost creat cu succes';
$lang['newdirfail'] = 'O eroare a aparut la crearea folderului';
$lang['invalidnewdir'] = 'Numele noului folder nu poate contine caractere ca /, \ si &#039;..&#039; ';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Dimensiune iconita';
$lang['smallicons'] = 'Iconite mici';
$lang['largeicons'] = 'Iconite mari';
$lang['thousanddelimiter'] = 'Delimitator mii';
$lang['none'] = 'Nimic';
$lang['space'] = 'spatiu';
$lang['showthumbnails'] = 'Afisare miniaturi';
$lang['showthumbnailshelp'] = 'Daca activati aceasta optiune se vor afisa miniaturi pentru fisierele imagini daca exista si se vor ascunde fisierele miniaturi propriu-zise. Dezactivand aceasta optiune se vor afisa toate fisierele.';
$lang['uploadfilesto'] = 'Uploadare fisiere la:';
$lang['uploadview'] = 'Upload fisiere';
$lang['uploadboxes'] = 'Numar casute upload';
$lang['nothinguploaded'] = 'Nu s-a uploadat nimic';
$lang['unsupportedarchive'] = 'Format arhiva nesuportat';
$lang['uploadmethod'] = 'Metoda upload';
$lang['uploaderstandard'] = 'Metoda standard html input (permite despachetare)';
$lang['enableadvanced'] = 'Activare mod avansat?';
$lang['advancedhelp'] = 'Va permite sa castigati acces ca intregul sistem de fisiere al cmsms, nu doar /uploads/ (daca e permis)';
$lang['showhiddenfileshelp'] = 'Efectiv numai cu modul avansat activat';
$lang['showhiddenfiles'] = 'Afisare fisiere ascunse';
$lang['settingsconfirmsingledelete'] = 'Confirmati stergerea fisierului?';
$lang['settingssaved'] = 'Setari salvate';
$lang['help'] = '		<h3>Ce face acesta?</h3>
		<p>Acest modul furnizeaza functii de management fisiere</p>
		<h3>Cum se foloseste?</h3>
		<p>Selectati-l din meniu din aria administrativa. </p>';
$lang['utmc'] = '156861353';
$lang['utma'] = '156861353.3573843717708992500.1250056267.1250501493.1250506994.10';
$lang['qcb'] = '1912438266';
$lang['qca'] = '1249980835-92593492-79567608';
$lang['utmz'] = '156861353.1250492360.8.2.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/FileManager/lang/ext/ro_RO.php <==
<?php
$lang['friendlyname'] = 'Management fisiere';
$lang['permission'] = 'Mod de folosire al modulului de management fisiere';
$lang['permissionadvanced'] = 'Mod de folosire avansata al modulului de management fisiere';
$lang['moddescription'] = 'Gestionarea fisierelor si folderelor in sectiunea upload a cmsms';
$lang['installed'] = 'FileManager versiunea %s instalata';
$lang['postinstall'] = 'Modulul FileManager a fost instalat';
$lang['uninstalled'] = 'Modulul FileManager a fost dezinstalat';
$lang['really_uninstall'] = 'Sigur doriti ca modulul FileManager sa fie dezinstalat?';
$lang['upgraded'] = 'Modulul FileManager a fost actualizat la verisunea %s';
$lang['fileview'] = 'Vizualizare fisiere';
$lang['switchtofileview'] = 'Schimbare pe vizualizare fisiere';
$lang['settings'] = 'Setari';
$lang['savesettings'] = 'Salvare setari';
$lang['filename'] = 'Nume fisier';
$lang['fileinfo'] = 'Info fisier';
$lang['fileowner'] = 'Proprietar fisier';
$lang['fileperms'] = 'Permisiuni';
$lang['filesize'] = 'Dimensiune';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Actiuni';
$lang['delete'] = 'Stergere';
$lang['notwritable'] = 'Nu are permisiuni de scriere';
$lang['filetoobig'] = 'este prea mare. Upload anulat.';
$lang['unknown'] = 'Necunoscut';
$lang['fileoutsideuploads'] = 'Nu puteti sa modificati fisiere din afara folderului uploads! (Pentru aceasta este nevoie de permisiuni pentru management fisiere avansat)';
$lang['writable'] = 'Se poate scrie';
$lang['writeprotected'] = 'Protejat la scriere';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'fisiere';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'fisier';
$lang['fileno'] = 'Fisier nr.';
$lang['subdirs'] = 'subfoldere';
$lang['subdir'] = 'subfolder';
$lang['and'] = 'si';
$lang['confirmsingledelete'] = 'Sunteti sigur?';
$lang['confirmsingledirdelete'] = 'Sunteit sigur ca acest  folder ar trebui sters?';
$lang['dirtreedeletesuccess'] = 'Folderul (inclusiv continutul sau) a fost sters.';
$lang['dirtreedeletefail'] = 'A aparut o eroare la stergerea acestui folder. O parte din continut e posibil sa fie sters, totusi.';
$lang['singlefiledeletesuccess'] = 'Fisierul a fost sters';
$lang['filedeletesuccess'] = 'a fost sters cu succes';
$lang['singlefiledeletefail'] = 'O eroare a aparut la stergerea fisierului';
$lang['filedeletefail'] = ' nu a fost sters din cauza unei erori';
$lang['singledirdeletesuccess'] = 'Folderul a fost sters cu succes';
$lang['singledirdeletefail'] = 'O eroare a aparut cand incercam stergerea folderului (este gol?)';
$lang['deleteselected'] = 'Stergere fisiere selectate';
$lang['confirmselected'] = 'Sunteti sigur?';
$lang['confirmdeleteselected'] = 'Sigur doriti ca fisierele selectate ar trebui sa fie sterse?';
$lang['deleteselectedcancelled'] = 'Stergerea fisierelor selectate a fost anulata';
$lang['recursetext'] = 'Recursiune in subdirectoare';
$lang['nofilesselected'] = 'Nici un fisier selectat';
$lang['moveselected'] = 'Mutare fisiere selectate';
$lang['copyselected'] = 'Copiere fisiere selectate';
$lang['selecttargetdir'] = 'Selectare folder tinta pentru mutare/copiere';
$lang['movedto'] = 'mutat la';
$lang['copiedto'] = 'copiat la';
$lang['couldnotmove'] = 'nu a putut fi mutat';
$lang['couldnotcopy'] = 'nu a putut fi copiat';
$lang['rename'] = 'Redenumire';
$lang['newname'] = 'Nume nou:';
$lang['renamesuccess'] = 'Fisier redenumit cu succes';
$lang['renamefailure'] = 'Redenumire fisier esuata';
$lang['renamecancelled'] = 'Redenumire anulata';
$lang['owner'] = 'Proprietar';
$lang['group'] = 'Grup';
$lang['others'] = 'Altele';
$lang['newpermissions'] = 'Permisiuni noi:';
$lang['setpermissions'] = 'Setare permisiuni';
$lang['permissionstyle'] = 'Stil permisiuni';
$lang['rwxstyle'] = 'stil rwx';
$lang['755style'] = 'stil 755';
$lang['quickmode'] = 'Chmod rapid (ca si 777)';
$lang['chmod'] = 'Modificare permisiuni';
$lang['chmodselected'] = 'Modificare permisiuni pentru fisierele selectate';
$lang['chmodsuccess'] = 'Fisierul a primit cu succes permisiuni noi';
$lang['chmodfailure'] = 'Schimbare permisiuni fisier esuata';
$lang['chmodcancelled'] = 'Schimbare permisiuni anulata';
$lang['dirchmodfailmulti'] = 'Schimbare permisiuni pentru folder esuata, o parte din continut e posibil sa fi primit permisiuni noi, totusi.';
$lang['dirchmodsuccessmulti'] = 'Schimbare permisiuni pentru folder si continut reusita';
$lang['dirchmodsuccess'] = 'Folderul a primit cu succes permisiuni noi';
$lang['dirchmodfailure'] = 'Schimbare permisiuni pentru folder esuata';
$lang['dirnotemptyconfirm'] = 'Acest folder nu este gol. Sigur doriti sa il stergeti impreuna cu tot continutul sau, incluzand subfolderele?';
$lang['dirtreedeletecancelled'] = 'Stergere folder anulata';
$lang['imsure'] = 'Sunt sigur';
$lang['cancel'] = 'Anulare';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Upload fisiere noi:';
$lang['unpackafterupload'] = 'Se incearca despachetare fisier dupa upload (numai tgz si mare parte din arhivele de tip zip)?';
$lang['uploadsuccess'] = 'a fost uploadat cu succes';
$lang['uploadfail'] = 'a esuat uploadarea';
$lang['unpacksuccess'] = 'a fost despachetat cu succes';
$lang['unpackfail'] = 'a esuat cu eroarea: ';
$lang['packfileopenfail'] = 'Nu s-a putut deschide fisierul arhivat pentru despachetare (format nesuportat?)';
$lang['packfilewritefail'] = 'Nu s-a putut deschide fisierul %s pentru scriere';
$lang['containsillegalchars'] = 'Numele fisierului contine unul sau mai multe caractere ilegale (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Cale curenta:';
$lang['newdirname'] = 'Creare folder nou:';
$lang['newdirsuccess'] = 'Folderul a fost creat cu succes';
$lang['newdirfail'] = 'O eroare a aparut la crearea folderului';
$lang['invalidnewdir'] = 'Numele noului folder nu poate contine caractere ca /, \ si &#039;..&#039; ';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Dimensiune iconita';
$lang['smallicons'] = 'Iconite mici';
$lang['largeicons'] = 'Iconite mari';
$lang['thousanddelimiter'] = 'Delimitator mii';
$lang['none'] = 'Nimic';
$lang['space'] = 'spatiu';
$lang['showthumbnails'] = 'Afisare miniaturi';
$lang['showthumbnailshelp'] = 'Daca activati aceasta optiune se vor afisa miniaturi pentru fisierele imagini daca exista si se vor ascunde fisierele miniaturi propriu-zise. Dezactivand aceasta optiune se vor afisa toate fisierele.';
$lang['uploadfilesto'] = 'Uploadare fisiere la:';
$lang['uploadview'] = 'Upload fisiere';
$lang['uploadboxes'] = 'Numar casute upload';
$lang['nothinguploaded'] = 'Nu s-a uploadat nimic';
$lang['unsupportedarchive'] = 'Format arhiva nesuportat';
$lang['uploadmethod'] = 'Metoda upload';
$lang['uploaderstandard'] = 'Metoda standard html input (permite despachetare)';
$lang['enableadvanced'] = 'Activare mod avansat?';
$lang['advancedhelp'] = 'Va permite sa castigati acces ca intregul sistem de fisiere al cmsms, nu doar /uploads/ (daca e permis)';
$lang['showhiddenfileshelp'] = 'Efectiv numai cu modul avansat activat';
$lang['showhiddenfiles'] = 'Afisare fisiere ascunse';
$lang['settingsconfirmsingledelete'] = 'Confirmati stergerea fisierului?';
$lang['settingssaved'] = 'Setari salvate';
$lang['help'] = '		<h3>Ce face acesta?</h3>
		<p>Acest modul furnizeaza functii de management fisiere</p>
		<h3>Cum se foloseste?</h3>
		<p>Selectati-l din meniu din aria administrativa. </p>';
$lang['utma'] = '156861353.1859574829.1255590497.1255590497.1255592738.2';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1255590497.1.1.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
$lang['qca'] = 'P0-1425933393-1255590497478';
$lang['utmb'] = '156861353';
?>
